@@ -1088,22 +1088,19 @@ def process_bcs(csv, mismatch_5p):
 
 
 def print_header():
-    print("")
-    print(
-        "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@")
-    print(
-        "@@@@@   @@@@   .@@   @@@@@@@          @@         @@@@@@    (@@@@@        @@@    @@@@@@@         @@    @@@    @")
-    print(
-        "@@@@   @@@@    @@   ,@@@@@@@@@    @@@@@    @@@   @@@@   (   @@@@   @@@   @@    @@@@@@@   @@@@@@@@@@   #   @@@@")
-    print(
-        "@@@   &@@@    @@    @@@@@@@@@%   @@@@@         @@@@(   @    @@@         @@    @@@@@@@         @@@@@     @@@@@@")
-    print(
-        "@@    @@@    @@    @@@@@@@@@@   @@@@@    @@    @@@          @@   .@@@@@@@*   @@@@@@@    @@@@@@@@.   @    @@@@@")
-    print(
-        "@@@       @@@@.        @@@@@   @@@@@&   @@@.   &   &@@@@    @    @@@@@@@@         @          @    @@@@    @@@@")
-    print(
-        "@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@")
-    print("")
+    logo=(" /$$   /$$ /$$   /$$                                  /$$                    \n"
+"| $$  | $$| $$  | $$                                 | $$                    \n"
+"| $$  | $$| $$ /$$$$$$    /$$$$$$  /$$$$$$   /$$$$$$ | $$  /$$$$$$  /$$   /$$\n"
+"| $$  | $$| $$|_  $$_/   /$$__  $$|____  $$ /$$__  $$| $$ /$$__  $$|  $$ /$$/\n"
+"| $$  | $$| $$  | $$    | $$  \__/ /$$$$$$$| $$  \ $$| $$| $$$$$$$$ \  $$$$/ \n"
+"| $$  | $$| $$  | $$ /$$| $$      /$$__  $$| $$  | $$| $$| $$_____/  >$$  $$ \n"
+"|  $$$$$$/| $$  |  $$$$/| $$     |  $$$$$$$| $$$$$$$/| $$|  $$$$$$$ /$$/\  $$\n"
+" \______/ |__/   \___/  |__/      \_______/| $$____/ |__/ \_______/|__/  \__/\n"
+"                                           | $$                              \n"
+"                                           | $$                              \n"
+"                                           |__/                              \n")
+
+    print(logo)
 
 
 def check_enough_space(output_directory, input_file,
